Name:           python-netcdf4
Version:        1.6.2
Release:        %mkrel 2
Summary:        Python/Numpy interface to netCDF

Group:          Development/Python
License:        MIT
URL:            https://github.com/Unidata/netcdf4-python
Source0:        https://github.com/Unidata/netcdf4-python/archive/netcdf4-python-%{version}.tar.gz
# No rpath for library
# https://code.google.com/p/netcdf4-python/issues/detail?id=138
Patch0:         netcdf4-python-1.4.0-norpath.patch
Patch1:         netcdf4-python-linking.patch
BuildRequires:  pkgconfig(netcdf)

%description
netCDF version 4 has many features not found in earlier versions of the
library and is implemented on top of HDF5. This module can read and write
files in both the new netCDF 4 and the old netCDF 3 format, and can create
files that are readable by HDF5 clients. The API modeled after
Scientific.IO.NetCDF, and should be familiar to users of that module.

Most new features of netCDF 4 are implemented, such as multiple unlimited
dimensions, groups and zlib data compression. All the new numeric data types
(such as 64 bit and unsigned integer types) are implemented. Compound and
variable length (vlen) data types are supported, but the enum and opaque data
types are not. Mixtures of compound and vlen data types (compound types
containing vlens, and vlens containing compound types) are not supported.

%package -n python3-netcdf4
Summary:        Python3/numpy interface to netCDF
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(cftime)
BuildRequires:  python3dist(cython)
BuildRequires:  python3dist(numpy)
BuildRequires:  python3-numpy-devel
Requires:       python3dist(cython)
Requires:       %{_lib}netcdf-plugins
%{?python_provide:%python_provide python3-netcdf4}

%description -n python3-netcdf4
netCDF version 4 has many features not found in earlier versions of the
library and is implemented on top of HDF5. This module can read and write
files in both the new netCDF 4 and the old netCDF 3 format, and can create
files that are readable by HDF5 clients. The API modeled after
Scientific.IO.NetCDF, and should be familiar to users of that module.

Most new features of netCDF 4 are implemented, such as multiple unlimited
dimensions, groups and zlib data compression. All the new numeric data types
(such as 64 bit and unsigned integer types) are implemented. Compound and
variable length (vlen) data types are supported, but the enum and opaque data
types are not. Mixtures of compound and vlen data types (compound types
containing vlens, and vlens containing compound types) are not supported.

%prep
%autosetup -p1 -n netcdf4-python-%{version}

%build
export NETCDF_PLUGIN_DIR=%{_libdir}/hdf5/plugin
%py3_build

%install
export NETCDF_PLUGIN_DIR=%{_libdir}/hdf5/plugin
%py3_install

# symlink identical plugins as they're copied during the build
rm -rf %{buildroot}%{python3_sitearch}/netCDF4/plugins/
ln -sf %{_libdir}/hdf5/plugin/  %{buildroot}%{python3_sitearch}/netCDF4/plugins

%check
cd test
export NO_NET=1
PYTHONPATH=../build/lib.%{python3_platform}-cpython-%{python3_version_nodots} %{__python3} run_all.py || :

%files -n python3-netcdf4
%doc Changelog docs examples README.md
%{python3_sitearch}/*
%{_bindir}/nc3tonc4
%{_bindir}/nc4tonc3
%{_bindir}/ncinfo


%changelog
* Tue Dec 06 2022 wally <wally> 1.6.2-2.mga9
+ Revision: 1918587
- build with netcdf hdf5 plugins
- fix tests
- fix linking

* Mon Dec 05 2022 eatdirt <eatdirt> 1.6.2-1.mga9
+ Revision: 1918330
- Upgrade to version 1.6.2
- Update to version 1.6.2

* Sat Apr 02 2022 umeabot <umeabot> 1.5.4-7.mga9
+ Revision: 1840636
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 1.5.4-6.mga9
+ Revision: 1782962
- Rebuild for python-3.10

* Sun Dec 12 2021 wally <wally> 1.5.4-5.mga9
+ Revision: 1761550
- rebuild for netcdf 4.8.1

* Tue Apr 20 2021 daviddavid <daviddavid> 1.5.4-4.mga9
+ Revision: 1717264
- rebuild for python 3.9

* Mon Oct 26 2020 akien <akien> 1.5.4-3.mga8
+ Revision: 1639577
- Rebuild against libnetcdf18

* Thu Oct 01 2020 pterjan <pterjan> 1.5.4-2.mga8
+ Revision: 1631503
- Rebuild for new netcdf on arm

* Fri Sep 18 2020 daviddavid <daviddavid> 1.5.4-1.mga8
+ Revision: 1628511
- new version: 1.5.4

* Sun Jul 05 2020 joequant <joequant> 1.5.3-1.mga8
+ Revision: 1602309
- update to 1.5.3
+ daviddavid <daviddavid>
- rebuild for new netcdf 4.7.3

* Sun Feb 16 2020 umeabot <umeabot> 1.4.2-5.mga8
+ Revision: 1532752
- Mageia 8 Mass Rebuild

* Tue Sep 17 2019 tv <tv> 1.4.2-4.mga8
+ Revision: 1442924
- rebuild for python-3.8

* Fri Aug 30 2019 wally <wally> 1.4.2-3.mga8
+ Revision: 1435609
- drop python2 support

* Tue Apr 23 2019 joequant <joequant> 1.4.2-2.mga7
+ Revision: 1394921
- rebuild with new libraries

* Wed Jan 09 2019 shlomif <shlomif> 1.4.2-1.mga7
+ Revision: 1353481
- Rebuild for python3 3.7

* Thu Nov 08 2018 daviddavid <daviddavid> 1.4.0-3.mga7
+ Revision: 1328951
- rebuild for new hdf5 1.10.4

* Sun Sep 23 2018 umeabot <umeabot> 1.4.0-2.mga7
+ Revision: 1300534
- Mageia 7 Mass Rebuild

* Mon Aug 13 2018 eatdirt <eatdirt> 1.4.0-1.mga7
+ Revision: 1251337
- Upgrade to version 1.4.0

* Thu May 10 2018 daviddavid <daviddavid> 1.2.9-1.mga7
+ Revision: 1227984
- new version: 1.2.9
- rename python-netcdf4 to python2-netcdf4
- add the python3 pkg
- use new python provides

* Tue Feb 02 2016 daviddavid <daviddavid> 1.0.2-7.mga6
+ Revision: 931500
- use new python macros

* Tue Feb 02 2016 umeabot <umeabot> 1.0.2-6.mga6
+ Revision: 931364
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.0.2-5.mga5
+ Revision: 743009
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.0.2-4.mga5
+ Revision: 729145
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.0.2-3.mga5
+ Revision: 688172
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Fri Nov 22 2013 nanardon <nanardon> 1.0.2-1.mga4
+ Revision: 552307
- Fix package Group
- imported package python-netcdf4


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 21 2013 Orion Poplawski <orion@cora.nwra.com> - 1.0.2-1
- Update to 1.0.2
- Remove bundled ordereddict (Bug #913528), require it on EL6
- Run tests

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-3.fix1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Sep 12 2012 Orion Poplawski <orion@cora.nwra.com> - 1.0-2.fix1
- Add patch to link only against netcdf

* Thu May 24 2012 Orion Poplawski <orion@cora.nwra.com> - 1.0-1.fix1
- Update to 1.0fix1

* Thu Apr 5 2012 Orion Poplawski <orion@cora.nwra.com> - 0.9.9-1
- Update to 0.9.9

* Thu Sep 8 2011 Orion Poplawski <orion@cora.nwra.com> - 0.9.7-1
- Initial package
